@@ -20,15 +20,19 @@ sql_vars={
 elastic_vars = {
     "__ip__" : "45.56.113.162",
     "__port__": 9200,
+    "__user__": "elastic",
+    "__password": "uZCxWGE35lD3lhc",
     "__es__": Elasticsearch(
         "45.56.113.162",
         port=9200,
+        user= "elastic",
+        password="uZCxWGE35lD3lhc"
         )
     
 }
 
 ############ 0 LOGGING #############
-def set_elastic_vars(__ip__=None, __port__=None):
+def set_elastic_vars(__ip__=None, __port__=None, __user__= None, __password__= None):
     """[summary]
 
     Args:
@@ -46,6 +50,9 @@ def set_elastic_vars(__ip__=None, __port__=None):
         elastic_vars["__es__"] = Elasticsearch(
             elastic_vars["__ip__"],
             port=elastic_vars["__port__"],
+            user=elastic_vars["__user__"],
+            password=elastic_vars["__password__"]
+            
         )
     return 1
 
